<?php

class CourseCatalogSettings {
    /**
     * Holds the values to be used in the fields callbacks
     */
    protected $options;
    protected $option_name = CCS_OPTION_NAME;
    protected $option_page_id = 'ccs-plugin-settings';

    // Default values
    protected $option_data = array(
        'ccs_url' => 'http://localhost/usimccs',
        'ccs_faculty_program_page' => '',
        'ccs_program_details_page' => '',
        'ccs_program_search_page' => '',
        'ccs_program_search_result_page' => '',
        'ccs_faculty_id_param' => 'fid',
        'ccs_program_id_param' => 'pid',
        'ccs_header_colors' => '',
        'ccs_tag_background_color' => '#a0ce4e',
        'ccs_tag_color' => '#ffffff'
    );

    /**
     * Start up
     */
    public function __construct()
    {
        add_action('admin_init', array($this, 'page_init'));
        add_action('admin_menu', array($this, 'add_plugin_page'));

        // Listen for the activate event
        register_activation_hook(CCS_PLUGIN_FILE, array($this, 'activate'));
    }

    /**
     * Add options page
     */
    public function add_plugin_page()
    {
        // This page will be under "Settings"
        add_options_page(
            'Course Catalog System Plugin Settings',
            'Course Catalog System',
            'manage_options',
            $this->option_page_id,
            array($this, 'create_admin_page')
        );
    }

    /**
     * Options page callback
     */
    public function create_admin_page()
    {
        // Set class property
        $this->options = get_option($this->option_name);
        ?>
        <div class="wrap">
            <h2>Course Catalog System</h2>
            <form method="post" action="options.php">
            <?php
                // This prints out all hidden setting fields
                settings_fields('ccs_option_group');
                do_settings_sections($this->option_page_id);
                submit_button();
            ?>
            </form>
        </div>
        <?php
    }

    /**
     * Register and add settings
     */
    public function page_init()
    {
        register_setting(
            'ccs_option_group', // Option group
            $this->option_name, // Option name
            array($this, 'sanitize') // Sanitize
        );

        add_settings_section(
            'setting_section_id',				// ID
            'Settings',							// Title
            array($this, 'print_section_info'),	// Callback
            $this->option_page_id					// Page
        );

        add_settings_field(
            'ccs_url',								// ID
            'Course Catalog System URL',			// Title
            array($this, 'ccs_url_callback'),		// Callback
            $this->option_page_id,					// Page
            'setting_section_id'					// Section
        );

        add_settings_field(
            'ccs_faculty_program_page',				// ID
            'Faculty Programme List page',			// Title
            array($this, 'ccs_faculty_program_page_callback'),		// Callback
            $this->option_page_id,					// Page
            'setting_section_id'					// Section
        );

        add_settings_field(
            'ccs_program_details_page',				// ID
            'Programme Details page',			// Title
            array($this, 'ccs_program_details_page_callback'),		// Callback
            $this->option_page_id,					// Page
            'setting_section_id'					// Section
        );

        add_settings_field(
            'ccs_program_search_page',				// ID
            'Programme Search page',			// Title
            array($this, 'ccs_program_search_page_callback'),		// Callback
            $this->option_page_id,					// Page
            'setting_section_id'					// Section
        );

        add_settings_field(
            'ccs_program_search_result_page',				// ID
            'Search Result page',			// Title
            array($this, 'ccs_program_search_result_page_callback'),		// Callback
            $this->option_page_id,					// Page
            'setting_section_id'					// Section
        );

        add_settings_field(
            'ccs_faculty_id_param',					// ID
            'Faculty ID parameter name',			// Title
            array($this, 'ccs_faculty_id_param_callback'),		// Callback
            $this->option_page_id,					// Page
            'setting_section_id'					// Section
        );

        add_settings_field(
            'ccs_program_id_param',					// ID
            'Program ID parameter name',			// Title
            array($this, 'ccs_program_id_param_callback'),		// Callback
            $this->option_page_id,					// Page
            'setting_section_id'					// Section
        );

        add_settings_field(
            'ccs_header_colors',					// ID
            'Header Colors (comma separated)',		// Title
            array($this, 'ccs_header_colors_callback'),		// Callback
            $this->option_page_id,					// Page
            'setting_section_id'					// Section
        );

        add_settings_field(
            'ccs_tag_background_color',								// ID
            'Tag Background Color',					// Title
            array($this, 'ccs_tag_background_color_callback'),		// Callback
            $this->option_page_id,					// Page
            'setting_section_id'					// Section
        );

        add_settings_field(
            'ccs_tag_color',								// ID
            'Tag Color',					// Title
            array($this, 'ccs_tag_color_callback'),		// Callback
            $this->option_page_id,					// Page
            'setting_section_id'					// Section
        );

    }

    /**
     * Sanitize each setting field as needed
     *
     * @param array $input Contains all settings fields as array keys
     */
    public function sanitize($input)
    {
        $new_input = array();

        if (isset($input['ccs_url']))
            $new_input['ccs_url'] = sanitize_text_field($input['ccs_url']);

        if (isset($input['ccs_faculty_program_page']))
        {
            $input['ccs_faculty_program_page'] = ltrim($input['ccs_faculty_program_page'], '/');
            $input['ccs_faculty_program_page'] = '/' . $input['ccs_faculty_program_page'];
            $new_input['ccs_faculty_program_page'] = sanitize_text_field($input['ccs_faculty_program_page']);
        }

        if (isset($input['ccs_program_details_page']))
        {
            $input['ccs_program_details_page'] = ltrim($input['ccs_program_details_page'], '/');
            $input['ccs_program_details_page'] = '/' . $input['ccs_program_details_page'];
            $new_input['ccs_program_details_page'] = sanitize_text_field($input['ccs_program_details_page']);
        }

        if (isset($input['ccs_program_search_page']))
        {
            $input['ccs_program_search_page'] = ltrim($input['ccs_program_search_page'], '/');
            $input['ccs_program_search_page'] = '/' . $input['ccs_program_search_page'];
            $new_input['ccs_program_search_page'] = sanitize_text_field($input['ccs_program_search_page']);
        }

        if (isset($input['ccs_program_search_result_page']))
        {
            $input['ccs_program_search_result_page'] = ltrim($input['ccs_program_search_result_page'], '/');
            $input['ccs_program_search_result_page'] = '/' . $input['ccs_program_search_result_page'];
            $new_input['ccs_program_search_result_page'] = sanitize_text_field($input['ccs_program_search_result_page']);
        }

        if (isset($input['ccs_faculty_id_param']))
        {
            $new_input['ccs_faculty_id_param'] = sanitize_text_field($input['ccs_faculty_id_param']);
        }
        else
        {
            $new_input['ccs_faculty_id_param'] = 'fid';
        }

        if (isset($input['ccs_program_id_param']))
        {
            $new_input['ccs_program_id_param'] = sanitize_text_field($input['ccs_program_id_param']);
        }
        else
        {
            $new_input['ccs_program_id_param'] = 'pid';
        }

        if (isset($input['ccs_header_colors']))
        {
            $new_input['ccs_header_colors'] = sanitize_text_field($input['ccs_header_colors']);
        }
        else
        {
            $new_input['ccs_header_colors'] = '#1f86c1,#dd3333';
        }

        if (isset($input['ccs_tag_background_color']))
        {
            $new_input['ccs_tag_background_color'] = sanitize_text_field($input['ccs_tag_background_color']);
        }
        else
        {
            $new_input['ccs_tag_background_color'] = '#a0ce4e';
        }

        if (isset($input['ccs_tag_color']))
        {
            $new_input['ccs_tag_color'] = sanitize_text_field($input['ccs_tag_color']);
        }
        else
        {
            $new_input['ccs_tag_color'] = '#ffffff';
        }

        return $new_input;
    }

    /**
     * Print the Section text
     */
    public function print_section_info()
    {
        //print 'Enter your settings below:';
    }

    /**
     * Get the settings option array and print one of its values
     */
    public function ccs_url_callback()
    {
        printf(
            '<input type="text" id="ccs_url" name="%s[ccs_url]" value="%s" size="30" />',
            $this->option_name,
            isset($this->options['ccs_url']) ? esc_attr($this->options['ccs_url']) : ''
        );
    }

    public function ccs_faculty_program_page_callback()
    {
        printf(
            '<input type="text" id="ccs_faculty_program_page" name="%s[ccs_faculty_program_page]" value="%s" size="30" />',
            $this->option_name,
            isset($this->options['ccs_faculty_program_page']) ? esc_attr($this->options['ccs_faculty_program_page']) : ''
        );
    }

    public function ccs_program_details_page_callback()
    {
        printf(
            '<input type="text" id="ccs_program_details_page" name="%s[ccs_program_details_page]" value="%s" size="30" />',
            $this->option_name,
            isset($this->options['ccs_program_details_page']) ? esc_attr($this->options['ccs_program_details_page']) : ''
        );
    }

    public function ccs_program_search_page_callback()
    {
        printf(
            '<input type="text" id="ccs_program_search_page" name="%s[ccs_program_search_page]" value="%s" size="30" />',
            $this->option_name,
            isset($this->options['ccs_program_search_page']) ? esc_attr($this->options['ccs_program_search_page']) : ''
        );
    }

    public function ccs_program_search_result_page_callback()
    {
        printf(
            '<input type="text" id="ccs_program_search_result_page" name="%s[ccs_program_search_result_page]" value="%s" size="30" />',
            $this->option_name,
            isset($this->options['ccs_program_search_result_page']) ? esc_attr($this->options['ccs_program_search_result_page']) : ''
        );
    }

    public function ccs_faculty_id_param_callback()
    {
        printf(
            '<input type="text" id="ccs_faculty_id_param" name="%s[ccs_faculty_id_param]" value="%s" size="5" />',
            $this->option_name,
            isset($this->options['ccs_faculty_id_param']) ? esc_attr($this->options['ccs_faculty_id_param']) : 'fid'
        );
    }

    public function ccs_program_id_param_callback()
    {
        printf(
            '<input type="text" id="ccs_program_id_param" name="%s[ccs_program_id_param]" value="%s" size="5" />',
            $this->option_name,
            isset($this->options['ccs_program_id_param']) ? esc_attr($this->options['ccs_program_id_param']) : 'pid'
        );
    }

    public function ccs_header_colors_callback()
    {
        printf(
            '<input type="text" id="ccs_header_colors" name="%s[ccs_header_colors]" value="%s" size="30" />',
            $this->option_name,
            isset($this->options['ccs_header_colors']) ? esc_attr($this->options['ccs_header_colors']) : '#1f86c1,#dd3333'
        );
    }

    public function ccs_tag_background_color_callback()
    {
        printf(
            '<input type="text" id="ccs_tag_background_color" name="%s[ccs_tag_background_color]" value="%s" size="7" />',
            $this->option_name,
            isset($this->options['ccs_tag_background_color']) ? esc_attr($this->options['ccs_tag_background_color']) : '#a0ce4e'
        );
    }

    public function ccs_tag_color_callback()
    {
        printf(
            '<input type="text" id="ccs_tag_color" name="%s[ccs_tag_color]" value="%s" size="7" />',
            $this->option_name,
            isset($this->options['ccs_tag_color']) ? esc_attr($this->options['ccs_tag_color']) : '#ffffff'
        );
    }

    public function activate() {
        update_option($this->option_name, $this->data);
    }

    public function deactivate() {
        delete_option($this->option_name);
    }
}

if (is_admin())
{
    $ccs_settings = new CourseCatalogSettings();
}
